@@ -26,23 +26,12 @@ module Debian.Control.String
 import qualified Control.Exception as E
 import Data.Char (toLower)
 import Data.List (find)
-import Text.ParserCombinators.Parsec (CharParser, parse, parseFromFile, sepEndBy, satisfy, oneOf, string, lookAhead, try, many, many1, (<|>), noneOf, char, eof)
-import System.IO (hGetContents)
 import Debian.Control.Common (ControlFunctions(parseControlFromFile, parseControlFromHandle, parseControl, lookupP, stripWS, asString),
                               Control'(Control), Paragraph'(Paragraph), Field'(Field, Comment),
                               mergeControls, fieldValue, removeField, prependFields, appendFields,
                               renameField, modifyField, raiseFields)
-import Text.PrettyPrint.ANSI.Leijen (Pretty(pretty), text, vcat, empty)
-
--- |This may have bad performance issues (why?)
-instance Pretty (Control' String) where
-    pretty (Control paragraphs) = vcat (map (\ p -> pretty p) paragraphs)
-instance Pretty (Paragraph' String) where
-    pretty (Paragraph fields) = vcat (map pretty fields ++ [empty])
-
-instance Pretty (Field' String) where
-    pretty (Field (name,value)) = text $ name ++":"++ value
-    pretty (Comment s) = text s
+import System.IO (hGetContents)
+import Text.ParserCombinators.Parsec (CharParser, parse, parseFromFile, sepEndBy, satisfy, oneOf, string, lookAhead, try, many, many1, (<|>), noneOf, char, eof)
 
 type Field = Field' String
 type Control = Control' String
